# Neuronum

![Neuronum Logo](https://www.neuronum.net/logo_pip.png "Neuronum")

Interact with the `Neuronum` Network to build, connect & automate economic data streams.

## Links and Resources
[![Website](https://img.shields.io/badge/Website-Neuronum-blue)](https://www.neuronum.net)
[![Documentation](https://img.shields.io/badge/Docs-Read%20now-green)](https://www.neuronum.net/docs)


## Installation
Install the library using pip:

```bash
pip install neuronum
